Vumi Freeswitch
===============

A Freeswitch eventsocket transport for `Vumi`_.

.. _Vumi: http://github.com/praekelt/vumi

|vfs-ci|_ |vfs-cover|_

.. |vfs-ci| image:: https://travis-ci.org/praekelt/vumi-freeswitch-esl.png?branch=develop
.. _vfs-ci: https://travis-ci.org/praekelt/vumi-freeswitch-esl

.. |vfs-cover| image:: https://coveralls.io/repos/praekelt/vumi-freeswitch-esl/badge.png?branch=develop
.. _vfs-cover: https://coveralls.io/r/praekelt/vumi-freeswitch-esl

You can contact the Vumi development team in the following ways:

* via *email* by joining the the `vumi-dev@googlegroups.com`_ mailing list
* on *irc* in *#vumi* on the `Freenode IRC network`_

.. _vumi-dev@googlegroups.com: https://groups.google.com/forum/?fromgroups#!forum/vumi-dev
.. _Freenode IRC network: https://webchat.freenode.net/?channels=#vumi

Issues can be filed in the GitHub issue tracker. Please don't use the issue
tracker for general support queries.
